# Generated by Django 5.2.1 on 2025-05-20 12:09

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("nyxboard", "0007_add_disabled_field"),
    ]

    operations = [
        migrations.AlterField(
            model_name="healthcheck",
            name="check_type",
            field=models.CharField(
                choices=[
                    ("http", "HTTP"),
                    ("json-http", "JSON-HTTP"),
                    ("tcp", "TCP"),
                    ("ping", "Ping"),
                    ("dns", "DNS"),
                    ("custom", "Custom"),
                ],
                default="http",
                max_length=20,
                verbose_name="Check Type",
            ),
        ),
    ]
