# Generated by Django 5.2.6 on 2025-10-05 06:21

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("nyxboard", "0008_alter_healthcheck_check_type"),
    ]

    operations = [
        migrations.AddField(
            model_name="healthcheck",
            name="data",
            field=models.JSONField(
                blank=True,
                default=dict,
                help_text="Check-type-specific configuration (e.g., DNS parameters)",
                verbose_name="Configuration Data",
            ),
        ),
        migrations.AlterField(
            model_name="healthcheck",
            name="url",
            field=models.CharField(
                help_text="Enter URL for HTTP checks or domain name for DNS checks",
                max_length=512,
                verbose_name="URL / Domain",
            ),
        ),
    ]
